==> fengoffice-1.7.5.tbz: www/fengoffice/language/zh_cn/emails.php <==
<?php return array(
	'new message' => '新消息',
	'new comment' => '新评论',
	'your account created' => '你的帐户已经被创建',
	'your password' => '你的密码',
	'milestone assigned to you' => '里程碑已经分派给你',
	'task assigned to you' => '任务已经分派给你',
	'hi john doe' => '你好 {0}，',
	'user password reseted desc' => '你的密码已经被重置，你现在可以使用下面的新资料登录到{0} 在 {1} :',
	'user password reseted username' => '用户名: {0}',
	'user password reseted password' => '密码: {0}（建议您尽快修改）',
	'dont reply wraning' => '系统通知，请勿回复!',
	'new message posted' => '新笔记"{0}" 已发布',
	'new task' => '新任务',
	'new task created' => '新任务“{0}”已被创建在工作区"“{1}”中',
	'view new message' => '查看新笔记',
	'view new task' => '查看新任务',
	'new comment posted' => '“{0}”上的新评论已被发布',
	'view new comment' => '查看新评论',
	'user created your account' => '{0}已为你创建了新帐户',
	'visit and login' => '访问{0}并登录为',
	'milestone assigned' => '里程碑“{0}”已分派给你',
	'task assigned' => '任务“{0}”已分派给你',
	'view assigned milestones' => '查看此里程碑',
	'view assigned tasks' => '查看此任务',
	'reply mail' => '回复',
	'write mail' => '写邮件',
	'mail to' => '到',
	'mail account' => '帐户',
	'mail account desc' => '邮件将发送到的帐户',
	'mail subject' => '主题',
	'mail CC' => '抄送',
	'mail CC desc' => '收件人将接收到本邮件的完全拷贝',
	'mail BCC' => '密送',
	'mail BCC desc' => '收件人将接收到本邮件的完全拷贝，但是其他收件人将不知道。',
	'mail from' => '从',
	'mail body' => '正文',
	'send mail' => '发送邮件',
	'smtp server' => 'SMTP 服务器',
	'mail account smtp server description' => 'SMTP 服务器是用来发送电子邮件的服务器',
	'smtp use auth' => 'SMTP 服务器认证',
	'mail account smtp use auth description' => '这个是你的SMTP服务器的认证信息，一般使用你的收件人认证信息。',
	'no smtp auth' => '不认证',
	'same as incoming' => '使用收件人信息',
	'smtp specific' => '输入SMTP用户名和密码',
	'smtp username' => 'SMTP 用户名',
	'mail account smtp username description' => 'SMTP 服务器的用户名',
	'smtp password' => 'SMTP 密码',
	'mail account smtp password description' => 'SMTP 服务器的密码',
	'smtp port' => 'SMTP 服务器端口',
	'mail account smtp port description' => '这是SMTP服务器监听的端口，缺省和大多数服务器都是25。',
	'outgoing transport type' => '安全连接',
	'mail account outgoing transport type description' => '设置为"ssl" 或者"tls"来启用安全连接',
	'smtp settings' => 'SMTP 设置',
	'format plain' => '普通文本格式',
	'format html' => 'HTML格式',
	'mail options' => '选项',
	'forward mail' => '转发',
	'reply to all mail' => '全部回复',
	'switch format warn' => '切换到文本方式将放弃所有的HTML的格式信息，是否继续?',
	'success mark objects' => '邮件已更新',
	'error mark email' => '错误更新电子邮件状态',
	'draft' => '草稿',
	'success save mail' => '草稿已保存',
	'discard' => '放弃',
	'mail address' => '电子邮件地址',
	'mail address description' => '电子邮件地址是其他人给你发送邮件时使用的地址。',
	'unread emails' => '未读邮件',
	'due_date reminder notification task' => '到期任务提醒',
	'due_date task reminder desc' => '任务 "{0}" 将于 "{1}" 到期。尚待完成',
	'due_date reminder notification milestone' => '到期里程碑提醒',
	'due_date milestone reminder desc' => '里程碑 "{0}" 将于 "{1}" 到期，尚待完成',
	'start reminder notification event' => '事件提醒',
	'start event reminder desc' => '事件 "{0}" 开始于 "{1}"',
	'task has been modified' => '任务 "{0}" 在工作区"{1}"中已被编辑',
	'task modified' => '任务已被编辑',
	'view task' => '显示任务',
	'view file' => '显示文件',
	'view message' => '显示笔记',
	'view comment' => '显示评论',
	'view company' => '显示公司',
	'view contact' => '显示联系人',
	'view mail account' => '显示邮件帐户',
	'view email' => '显示电子邮件',
	'view emailunclassified' => '显示未分类电子邮件',
	'view chart' => '显示图表',
	'view event' => '显示事件',
	'view file_revision' => '显示文件版本',
	'view form' => '显示表单',
	'view milestone' => '显示里程碑',
	'view webpage' => '显示网站链接',
	'view project' => '显示工作区',
	'view tag' => '显示标签',
	'view template' => '显示模板',
	'view timeslot' => '显示时段',
	'view user' => '显示用户',
	'original message' => '原始信息',
	'mail sent' => '发送邮件',
	'new notification task' => '新任务“{0}”',
	'new notification task desc' => '新任务“{0}”已由{1}添加。',
	'new notification event' => '新事件“{0}”',
	'new notification event desc' => '新事件“{0}”已由{1}添加。',
	'new notification company' => '新公司“{0}”',
	'new notification company desc' => '新公司“{0}”已由{1}添加。',
	'new notification contact' => '新联系人“{0}”',
	'new notification contact desc' => '新联系人“{0}”已由{1}添加。',
	'new notification message' => '新笔记“{0}”',
	'new notification message desc' => '新笔记“{0}”已由{1}添加。',
	'new notification file' => '新文件“{0}”',
	'new notification file desc' => '新文件“{0}”已由{1}添加。',
	'new notification webpage' => '新的网站链接“{0}”',
	'new notification webpage desc' => '新网站链接“{0}”已由{1}添加。',
	'new notification milestone' => '新里程碑“{0}”',
	'new notification milestone desc' => '新里程碑“{0}”已由{1}添加。',
	'modified notification task' => '任务“{0}”已被编辑',
	'modified notification task desc' => '任务“{0}”已由{1}编辑。',
	'modified notification event' => '事件“{0}”已被编辑',
	'modified notification event desc' => '事件“{0}”已由{1}编辑。',
	'modified notification company' => '公司“{0}”已被编辑',
	'modified notification company desc' => '公司“{0}”已由{1}编辑。',
	'modified notification contact' => '联系人“{0}”已被编辑',
	'modified notification contact desc' => '联系人“{0}”已由{1}编辑。',
	'modified notification message' => '笔记“{0}”已被编辑',
	'modified notification message desc' => '笔记“{0}”已由{1}编辑。',
	'modified notification file' => '文件“{0}”已被编辑',
	'modified notification file desc' => '文件“{0}”已由{1}编辑。',
	'modified notification webpage' => '网站链接“{0}”已被编辑',
	'modified notification webpage desc' => '网站链接“{0}”已由{1}编辑。',
	'modified notification milestone' => '里程碑“{0}”已被编辑',
	'modified notification milestone desc' => '里程碑“{0}”已由{1}编辑。',
	'deleted notification task' => '任务“{0}”已被送到回收站',
	'deleted notification task desc' => '任务“{0}”已被{1}放入回收站。',
	'deleted notification event' => '事件“{0}”已被送到回收站',
	'deleted notification event desc' => '事件“{0}”已被{1}放入回收站。',
	'deleted notification company' => '公司“{0}”已被送到回收站',
	'deleted notification company desc' => '公司“{0}”已被{1}放入回收站。',
	'deleted notification contact' => '联系人“{0}”已被送到回收站',
	'deleted notification contact desc' => '联系人“{0}”已被{1}放入回收站。',
	'deleted notification message' => '笔记“{0}”已被送到回收站',
	'deleted notification message desc' => '笔记“{0}”已被{1}放入回收站。',
	'deleted notification file' => '文件“{0}”已被送到回收站',
	'deleted notification file desc' => '文件“{0}”已被{1}放入回收站。',
	'deleted notification webpage' => '网站链接“{0}”已被送到回收站',
	'deleted notification webpage desc' => '网站链接“{0}”已被{1}放入回收站。',
	'deleted notification milestone' => '里程碑“{0}”已被送到回收站',
	'deleted notification milestone desc' => '里程碑“{0}”已被{1}放入回收站。',
	'closed notification task' => '任务“{0}”已经完成',
	'closed notification task desc' => '任务“{0}”已由{1}完成。',
	'closed notification milestone' => '里程碑“{0}”已经完成',
	'closed notification milestone desc' => '里程碑“{0}”已由{1}完成。',
	'password expiration reminder' => '密码到期提醒',
	'password expires days' => '您的密码将在{0}天内到期',
	'mail format options' => '格式',
	'start event reminder' => '事件提醒',
	'new notification comment' => '“{0}”上有新评论',
	'new notification comment desc' => '{1}在“{0}”上添加了一条新评论。',
	'modified notification email' => '邮件“{0}”被修改',
	'modified notification email desc' => '邮件“{0}”被 {1} 修改。',
	'deleted notification email' => '邮件“{0}”被放入回收站',
	'deleted notification email desc' => '邮件“{0}”被 {1} 放入回收站。',
	'mail attachments' => '邮件附件',
	'select attachment' => '选择并上传附件',
	'attach from workspace' => '从工作区选择',
	'attach from file system' => '从本地电脑选择',
	'subscribed notification task' => '订阅到任务“{0}”',
	'subscribed notification task desc' => '您被 {1} 设置成任务“{0}”的订户。',
	'subscribed notification event' => '订阅到事件“{0}”',
	'subscribed notification event desc' => '您被 {1} 设置成事件“{0}”的订户。',
	'subscribed notification company' => '订阅到公司“{0}”',
	'subscribed notification company desc' => '您被 {1} 设置成公司“{0}”的订户。',
	'subscribed notification contact' => '订阅到联系人“{0}”',
	'subscribed notification contact desc' => '您被 {1} 设置成联系人“{0}”的订户。',
	'subscribed notification message' => '订阅到笔记“{0}”',
	'subscribed notification message desc' => '您被 {1} 设置成笔记“{0}”的订户。',
	'subscribed notification file' => '订阅到文件“{0}”',
	'subscribed notification file desc' => '您被 {1} 设置成文件“{0}”的订户。',
	'subscribed notification webpage' => '订阅到Web链接“{0}”',
	'subscribed notification webpage desc' => '您被 {1} 设置成Web链接“{0}”的订户。',
	'subscribed notification milestone' => '订阅到里程碑“{0}”',
	'subscribed notification milestone desc' => '您被 {1} 设置成里程碑“{0}”的订户。',
	'subscribed notification email' => '订阅到邮件“{0}”',
	'subscribed notification email desc' => '您被 {1} 设置成邮件“{0}”的订户。',
	'sent mails sync' => '已发邮件同步设置（仅供IMAP）',
	'connnection security' => '连接安全',
	'select folder for outbox' => '选择您的发件箱文件夹',
	'cant find user' => '无法找到所需用户',
	'cant find account' => '无法找到所需邮件账户',
	'sync complete' => '完成同步',
	'invalid sync settings' => '同步设置无效。无法与服务器建立连接。',
); ?>

==> fengoffice-2.0.0.tbz: www/fengoffice/language/zh_cn/emails.php <==
<?php return array(
	'new message' => '新消息',
	'new comment' => '新评论',
	'your account created' => '你的帐户已经被创建',
	'your password' => '你的密码',
	'milestone assigned to you' => '里程碑已经分派给你',
	'task assigned to you' => '任务已经分派给你',
	'hi john doe' => '你好 {0}',
	'user password reseted desc' => '你的密码已经被重置，你现在可以使用下面的新资料登录到{0} 在 {1} :',
	'user password reseted username' => '用户名: {0}',
	'user password reseted password' => '密码: {0}',
	'dont reply wraning' => '这是一个系统通知，不要回复这个邮件!',
	'new message posted' => '新信息"{0}" 已经被发布',
	'new task' => '新任务',
	'new task created' => '新任务"{0}" 已经被创建在工作区"{1}"中',
	'view new message' => '显示新消息',
	'view new task' => '显示新任务',
	'new comment posted' => '新的评论在"{0}"上已经被发布',
	'view new comment' => '显示新评论',
	'user created your account' => '{0}已为你创建了新帐户',
	'visit and login' => '访问 {0} 和登录通过',
	'milestone assigned' => '里程碑 "{0}" 已经分派给你',
	'task assigned' => '任务 "{0}" 已经分派给你',
	'view assigned milestones' => '显示这个里程碑',
	'view assigned tasks' => '显示这个任务',
	'reply mail' => '回复',
	'write mail' => '写邮件',
	'mail to' => '到',
	'mail account' => '帐户',
	'mail account desc' => '邮件将发送到的帐户',
	'mail subject' => '主题',
	'mail CC' => '抄送',
	'mail CC desc' => '收件人将接收到本邮件的完全拷贝',
	'mail BCC' => '密送',
	'mail BCC desc' => '收件人将接收到本邮件的完全拷贝，但是其他收件人将不知道。',
	'mail from' => '从',
	'mail body' => '正文',
	'send mail' => '发送邮件',
	'smtp server' => 'SMTP 服务器',
	'mail account smtp server description' => 'SMTP 服务器是用来发送电子邮件的服务器',
	'smtp use auth' => 'SMTP 服务器认证',
	'mail account smtp use auth description' => '这个是你的SMTP服务器的认证信息，一般使用你的收件人认证信息。',
	'no smtp auth' => '不认证',
	'same as incoming' => '使用收件人信息',
	'smtp specific' => '输入SMTP用户名和密码',
	'smtp username' => 'SMTP 用户名',
	'mail account smtp username description' => 'SMTP 服务器的用户名',
	'smtp password' => 'SMTP 密码',
	'mail account smtp password description' => 'SMTP 服务器的密码',
	'smtp port' => 'SMTP 服务器端口',
	'mail account smtp port description' => ' 这是SMTP服务器监听的端口，缺省和大多数服务器都是25。',
	'outgoing transport type' => '安全连接',
	'mail account outgoing transport type description' => '设置为"ssl" 或者"tls"来启用安全连接',
	'smtp settings' => 'SMTP 设置',
	'format plain' => '普通文本格式',
	'format html' => 'HTML格式',
	'mail options' => '选项',
	'forward mail' => '转发',
	'reply to all mail' => '全部回复',
	'switch format warn' => '切换到文本方式将放弃所有的HTML的格式信息，是否继续?',
	'success mark objects' => '邮件已更新',
	'error mark email' => '错误更新电子邮件状态',
	'draft' => '草稿',
	'success save mail' => '草稿已保存',
	'discard' => '放弃',
	'mail address' => '电子邮件地址',
	'mail address description' => '电子邮件地址是其他人给你发送邮件时使用的地址。',
	'unread emails' => '未读邮件',
	'due_date reminder notification task' => '到期任务提醒',
	'due_date task reminder desc' => '任务 "{0}" 将于 "{1}" 到期。尚待完成',
	'due_date reminder notification milestone' => '到期里程碑提醒',
	'due_date milestone reminder desc' => '里程碑 "{0}" 将于 "{1}" 到期，尚待完成',
	'start reminder notification event' => '事件提醒',
	'start event reminder desc' => '事件 "{0}" 开始于 "{1}"',
	'task has been modified' => '任务 "{0}" 在工作区"{1}"中已被编辑',
	'task modified' => '任务已被编辑',
	'view task' => '显示任务',
	'view file' => '显示文件',
	'view message' => '显示笔记',
	'view comment' => '显示评论',
	'view company' => '显示公司',
	'view contact' => '显示联系人',
	'view mail account' => '显示邮件帐户',
	'view email' => '显示电子邮件',
	'view emailunclassified' => '显示未分类电子邮件',
	'view chart' => '显示图表',
	'view event' => '显示事件',
	'view file_revision' => '显示文件版本',
	'view form' => '显示表单',
	'view milestone' => '显示里程碑',
	'view webpage' => '显示网站链接',
	'view project' => '显示工作区',
	'view tag' => '显示标签',
	'view template' => '显示模板',
	'view timeslot' => '显示时段',
	'view user' => '显示用户',
	'original message' => '原始信息',
	'mail sent' => '发送邮件',
	'new notification task' => '新任务“{0}”',
	'new notification task desc' => '新任务“{0}”已由{1}添加。',
	'new notification event' => '新事件“{0}”',
	'new notification event desc' => '新事件“{0}”已由{1}添加。',
	'new notification company' => '新公司“{0}”',
	'new notification company desc' => '新公司“{0}”已由{1}添加。',
	'new notification contact' => '新联系人“{0}”',
	'new notification contact desc' => '新联系人“{0}”已由{1}添加。',
	'new notification message' => '新笔记“{0}”',
	'new notification message desc' => '新笔记“{0}”已由{1}添加。',
	'new notification file' => '新文件“{0}”',
	'new notification file desc' => '新文件“{0}”已由{1}添加。',
	'new notification webpage' => '新的网站链接“{0}”',
	'new notification webpage desc' => '新网站链接“{0}”已由{1}添加。',
	'new notification milestone' => '新里程碑“{0}”',
	'new notification milestone desc' => '新里程碑“{0}”已由{1}添加。',
	'modified notification task' => '任务“{0}”已被编辑',
	'modified notification task desc' => '任务“{0}”已由{1}编辑。',
	'modified notification event' => '事件“{0}”已被编辑',
	'modified notification event desc' => '事件“{0}”已由{1}编辑。',
	'modified notification company' => '公司“{0}”已被编辑',
	'modified notification company desc' => '公司“{0}”已由{1}编辑。',
	'modified notification contact' => '联系人“{0}”已被编辑',
	'modified notification contact desc' => '联系人“{0}”已由{1}编辑。',
	'modified notification message' => '笔记“{0}”已被编辑',
	'modified notification message desc' => '笔记“{0}”已由{1}编辑。',
	'modified notification file' => '文件“{0}”已被编辑',
	'modified notification file desc' => '文件“{0}”已由{1}编辑。',
	'modified notification webpage' => '网站链接“{0}”已被编辑',
	'modified notification webpage desc' => '网站链接“{0}”已由{1}编辑。',
	'modified notification milestone' => '里程碑“{0}”已被编辑',
	'modified notification milestone desc' => '里程碑“{0}”已由{1}编辑。',
	'deleted notification task' => '任务“{0}”已被送到回收站',
	'deleted notification task desc' => '任务“{0}”已被{1}放入回收站。',
	'deleted notification event' => '事件“{0}”已被送到回收站',
	'deleted notification event desc' => '事件“{0}”已被{1}放入回收站。',
	'deleted notification company' => '公司“{0}”已被送到回收站',
	'deleted notification company desc' => '公司“{0}”已被{1}放入回收站。',
	'deleted notification contact' => '联系人“{0}”已被送到回收站',
	'deleted notification contact desc' => '联系人“{0}”已被{1}放入回收站。',
	'deleted notification message' => '笔记“{0}”已被送到回收站',
	'deleted notification message desc' => '笔记“{0}”已被{1}放入回收站。',
	'deleted notification file' => '文件“{0}”已被送到回收站',
	'deleted notification file desc' => '文件“{0}”已被{1}放入回收站。',
	'deleted notification webpage' => '网站链接“{0}”已被送到回收站',
	'deleted notification webpage desc' => '网站链接“{0}”已被{1}放入回收站。',
	'deleted notification milestone' => '里程碑“{0}”已被送到回收站',
	'deleted notification milestone desc' => '里程碑“{0}”已被{1}放入回收站。',
	'closed notification task' => '任务“{0}”已经完成',
	'closed notification task desc' => '任务“{0}”已由{1}完成。',
	'closed notification milestone' => '里程碑“{0}”已经完成',
	'closed notification milestone desc' => '里程碑“{0}”已由{1}完成。',
	'password expiration reminder' => '密码到期提醒',
	'password expires days' => '您的密码将在{0}天内到期',
	'mail format options' => '格式',
	'start event reminder' => '事件提醒',
	'new notification comment' => '“{0}”上有新评论',
	'new notification comment desc' => ' {1} 在“{0}”上添加了一条新评论。',
	'modified notification email' => '邮件“{0}”被修改',
	'modified notification email desc' => '邮件“{0}”被 {1} 修改。',
	'deleted notification email' => '邮件“{0}”被放入回收站',
	'deleted notification email desc' => '邮件“{0}”被 {1} 放入回收站。',
	'mail attachments' => '邮件附件',
	'select attachment' => '选择并上传附件',
	'attach from workspace' => '从工作区选择',
	'attach from file system' => '从本地电脑选择',
	'subscribed notification task' => '订阅到任务“{0}”',
	'subscribed notification task desc' => '您被 {1} 设置成任务“{0}”的订户。',
	'subscribed notification event' => '订阅到事件“{0}”',
	'subscribed notification event desc' => '您被 {1} 设置成事件“{0}”的订户。',
	'subscribed notification company' => '订阅到公司“{0}”',
	'subscribed notification company desc' => '您被 {1} 设置成公司“{0}”的订户。',
	'subscribed notification contact' => '订阅到联系人“{0}”',
	'subscribed notification contact desc' => '您被 {1} 设置成联系人“{0}”的订户。',
	'subscribed notification message' => '订阅到笔记“{0}”',
	'subscribed notification message desc' => '您被 {1} 设置成笔记“{0}”的订户。',
	'subscribed notification file' => '订阅到文件“{0}”',
	'subscribed notification file desc' => '您被 {1} 设置成文件“{0}”的订户。',
	'subscribed notification webpage' => '订阅到Web链接“{0}”',
	'subscribed notification webpage desc' => '您被 {1} 设置成Web链接“{0}”的订户。',
	'subscribed notification milestone' => '订阅到里程碑“{0}”',
	'subscribed notification milestone desc' => '您被 {1} 设置成里程碑“{0}”的订户。',
	'subscribed notification email' => '订阅到邮件“{0}”',
	'subscribed notification email desc' => '您被 {1} 设置成邮件“{0}”的订户。',
); ?>
